summaryrefslogtreecommitdiffstats
path: root/src/H5FDsubfiling_priv.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5FDsubfiling_priv.h')
-rw-r--r--src/H5FDsubfiling_priv.h22
1 files changed, 13 insertions, 9 deletions
diff --git a/src/H5FDsubfiling_priv.h b/src/H5FDsubfiling_priv.h
index d26bf4c..4753423 100644
--- a/src/H5FDsubfiling_priv.h
+++ b/src/H5FDsubfiling_priv.h
@@ -326,15 +326,19 @@ typedef struct {
*/
typedef struct {
/* {Datasize, Offset, FileID} */
- int64_t header[3]; /* The basic RPC input plus */
- int tag; /* the supplied OPCODE tag */
- int source; /* Rank of who sent the message */
- int subfile_rank; /* The IOC rank */
- hid_t context_id; /* context to be used to complete */
- double start_time; /* the request, + time of receipt */
- /* from which we calc Time(queued) */
- void *buffer; /* for writes, we keep the buffer */
- int completed; /* around for awhile... */
+ int64_t header[3]; /* The basic RPC input plus */
+ int tag; /* the supplied OPCODE tag */
+ int source; /* Rank of who sent the message */
+ int subfile_rank; /* The IOC rank */
+ hid_t context_id; /* context to be used to complete */
+ double start_time; /* the request, + time of receipt */
+ /* from which we calc Time(queued) */
+ void *buffer; /* for writes, we keep the buffer */
+ /* around for awhile... */
+ volatile int in_progress; /* Not used! */
+ volatile int serialize; /* worker thread needs to wait while true */
+ volatile int dependents; //* If current work item has dependents */
+ int depend_id; /* work queue index of the dependent */
} sf_work_request_t;
typedef struct { /* Format of a context map entry */